.. _orion:

orion
=====

.. currentmodule:: orion

Orion
~~~~~

.. autosummary::
   :toctree: api/

   Orion
   Orion.fit
   Orion.detect
   Orion.evaluate
   Orion.save
   Orion.load

Functional API
~~~~~~~~~~~~~~

.. autosummary::
   :toctree: api/

   fit_pipeline
   detect_anomalies
   evaluate_pipeline

Benchmark
~~~~~~~~~

.. autosummary::
   :toctree: api/

   benchmark.benchmark